==> haskell-genvalidity-0.11.0.0-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity
version:              0.11.0.0
visibility:           public
id:                   genvalidity-0.11.0.0-H2Y3bOSDy8y5H5Cm9yuTt0
key:                  genvalidity-0.11.0.0-H2Y3bOSDy8y5H5Cm9yuTt0
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  ae41059b98c6ae7eebf9399aef29ded1
exposed:              True
exposed-modules:
    Data.GenRelativeValidity Data.GenValidity Data.GenValidity.Utils

hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-8.10.2/site-local/genvalidity-0.11.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/genvalidity-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/genvalidity-0.11.0.0
hs-libraries:         HSgenvalidity-0.11.0.0-H2Y3bOSDy8y5H5Cm9yuTt0
depends:
    QuickCheck-2.14.1-ImMnmQnYyzf4BNCbXbRnTg base-4.14.1.0
    random-1.2.0-1XErNwNJzZZFg41vgbJp5j
    validity-0.11.0.0-GeBuj4xt1dc8ImWwH9j73b

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-0.11.0.0-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity
version:              0.11.0.0
visibility:           public
id:                   genvalidity-0.11.0.0-4nxOK6ljyiJH3CwntnIP3X
key:                  genvalidity-0.11.0.0-4nxOK6ljyiJH3CwntnIP3X
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  0645633d509c1744db37dd0b5a925520
exposed:              True
exposed-modules:
    Data.GenRelativeValidity Data.GenValidity Data.GenValidity.Utils

hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-8.10.2/site-local/genvalidity-0.11.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/genvalidity-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/genvalidity-0.11.0.0
hs-libraries:         HSgenvalidity-0.11.0.0-4nxOK6ljyiJH3CwntnIP3X
depends:
    QuickCheck-2.14.1-64ImYjtdVDWOmMrx53wi base-4.14.1.0
    random-1.2.0-9ZKOj3LHVp86TAE4mLSgtI
    validity-0.11.0.0-IJoS8TafVwAA5R4Sj8vsJr

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
